pub struct CategoryCount {
pub category: Option<String>,
pub count: Option<i64>,
}Expand description
Represents the count of a single category within the cluster.
This type is not used in any activity, and only used as part of another schema.
Fields
category: Option<String>The name of category.
count: Option<i64>The count of training samples matching the category within the cluster.