pub struct StagePerformanceStandaloneInsight {
pub bi_engine_reasons: Option<Vec<BiEngineReason>>,
pub high_cardinality_joins: Option<Vec<HighCardinalityJoin>>,
pub insufficient_shuffle_quota: Option<bool>,
pub partition_skew: Option<PartitionSkew>,
pub slot_contention: Option<bool>,
pub stage_id: Option<i64>,
}Expand description
Standalone performance insights for a specific stage.
This type is not used in any activity, and only used as part of another schema.
Fields
bi_engine_reasons: Option<Vec<BiEngineReason>>Output only. If present, the stage had the following reasons for being disqualified from BI Engine execution.
high_cardinality_joins: Option<Vec<HighCardinalityJoin>>Output only. High cardinality joins in the stage.
insufficient_shuffle_quota: Option<bool>Output only. True if the stage has insufficient shuffle quota.
partition_skew: Option<PartitionSkew>Output only. Partition skew in the stage.
slot_contention: Option<bool>Output only. True if the stage has a slot contention issue.
stage_id: Option<i64>Output only. The stage id that the insight mapped to.