Struct google_bigquery2::api::StandardSqlDataType [−][src]
The type of a variable, e.g., a function argument. Examples: INT64: {type_kind=“INT64”} ARRAY: {type_kind=“ARRAY”, array_element_type=“STRING”} STRUCT>: {type_kind=“STRUCT”, struct_type={fields=[ {name=“x”, type={type_kind=“STRING”}}, {name=“y”, type={type_kind=“ARRAY”, array_element_type=“DATE”}} ]}}
This type is not used in any activity, and only used as part of another schema.
Fields
array_element_type: Option<Option<Box<StandardSqlDataType>>>The type of the array’s elements, if type_kind = “ARRAY”.
struct_type: Option<StandardSqlStructType>The fields of this struct, in order, if type_kind = “STRUCT”.
type_kind: Option<String>Required. The top level type of this field. Can be any standard SQL data type (e.g., “INT64”, “DATE”, “ARRAY”).