Struct google_bigquery2::EncryptionConfiguration [−][src]
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
kms_key_name: Option<String>
[Optional] Describes the Cloud KMS encryption key that will be used to protect destination BigQuery table. The BigQuery Service Account associated with your project requires access to this encryption key.