Struct google_bigquery2::JobStatistics3
source · pub struct JobStatistics3 {
pub output_rows: Option<String>,
pub bad_records: Option<String>,
pub input_files: Option<String>,
pub output_bytes: Option<String>,
pub input_file_bytes: Option<String>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
output_rows: Option<String>[Output-only] Number of rows imported in a load job. Note that while an import job is in the running state, this value may change.
bad_records: Option<String>[Output-only] The number of bad records encountered. Note that if the job has failed because of more bad records encountered than the maximum allowed in the load job configuration, then this number can be less than the total number of bad records present in the input data.
input_files: Option<String>[Output-only] Number of source files in a load job.
output_bytes: Option<String>[Output-only] Size of the loaded data in bytes. Note that while a load job is in the running state, this value may change.
input_file_bytes: Option<String>[Output-only] Number of bytes of source data in a load job.