Struct google_bigquery2::JobStatus
source · pub struct JobStatus {
pub state: Option<String>,
pub errors: Option<Vec<ErrorProto>>,
pub error_result: Option<ErrorProto>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
state: Option<String>[Output-only] Running state of the job.
errors: Option<Vec<ErrorProto>>[Output-only] The first errors encountered during the running of the job. The final message includes the number of errors that caused the process to stop. Errors here do not necessarily mean that the job has completed or was unsuccessful.
error_result: Option<ErrorProto>[Output-only] Final error result of the job. If present, indicates that the job has completed and was unsuccessful.