[−][src]Struct google_bigquery2::ModelDefinitionModelOptions
[Output-only, Beta] Model options used for the first training run. These options are immutable for subsequent training runs. Default values are used for any options not specified in the input query.
This type is not used in any activity, and only used as part of another schema.
Fields
labels: Option<Vec<String>>no description provided
loss_type: Option<String>no description provided
model_type: Option<String>no description provided