Struct google_bigquery2::QueryParameterType [−][src]
pub struct QueryParameterType {
pub struct_types: Option<Vec<QueryParameterTypeStructTypes>>,
pub type_: Option<String>,
pub array_type: Option<Option<Box<QueryParameterType>>>,
}There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
struct_types: Option<Vec<QueryParameterTypeStructTypes>>
[Optional] The types of the fields of this struct, in order, if this is a struct.
type_: Option<String>
[Required] The top level type of this field.
array_type: Option<Option<Box<QueryParameterType>>>
[Optional] The type of the array's elements, if this is an array.