Struct google_bigquery2::QueryParameterValue
source · pub struct QueryParameterValue {
pub struct_values: Option<HashMap<String, QueryParameterValue>>,
pub array_values: Option<Vec<QueryParameterValue>>,
pub value: Option<String>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
struct_values: Option<HashMap<String, QueryParameterValue>>[Optional] The struct field values, in order of the struct type’s declaration.
array_values: Option<Vec<QueryParameterValue>>[Optional] The array values, if this is an array type.
value: Option<String>[Optional] The value of this value, if a simple scalar type.