Struct google_bigquery2::Streamingbuffer [−][src]
pub struct Streamingbuffer {
pub estimated_bytes: Option<String>,
pub estimated_rows: Option<String>,
pub oldest_entry_time: Option<String>,
}There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
estimated_bytes: Option<String>
[Output-only] A lower-bound estimate of the number of bytes currently in the streaming buffer.
estimated_rows: Option<String>
[Output-only] A lower-bound estimate of the number of rows currently in the streaming buffer.
oldest_entry_time: Option<String>
[Output-only] Contains the timestamp of the oldest entry in the streaming buffer, in milliseconds since the epoch, if the streaming buffer is available.