Struct google_bigquery2::TableListTables [] [src]

pub struct TableListTables {
    pub kind: Option<String>,
    pub friendly_name: Option<String>,
    pub labels: Option<HashMap<String, String>>,
    pub type_: Option<String>,
    pub table_reference: Option<TableReference>,
    pub id: Option<String>,
}

Tables in the requested dataset.

This type is not used in any activity, and only used as part of another schema.

Fields

The resource type.

The user-friendly name for this table.

[Experimental] The labels associated with this table. You can use these to organize and group your tables.

The type of table. Possible values are: TABLE, VIEW.

A reference uniquely identifying the table.

An opaque ID of the table