Struct google_bigquery2::TableRow [−][src]
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
f: Option<Vec<TableCell>>
Represents a single row in the result set, consisting of one or more fields.