Struct google_bigquery2::DatasetAccess
source · pub struct DatasetAccess {
pub domain: Option<String>,
pub role: Option<String>,
pub user_by_email: Option<String>,
pub special_group: Option<String>,
pub group_by_email: Option<String>,
pub view: Option<TableReference>,
}Expand description
[Optional] An array of objects that define dataset access for one or more entities. You can set this property when inserting or updating a dataset in order to control who is allowed to access the data. If unspecified at dataset creation time, BigQuery adds default dataset access for the following entities: access.specialGroup: projectReaders; access.role: READER; access.specialGroup: projectWriters; access.role: WRITER; access.specialGroup: projectOwners; access.role: OWNER; access.userByEmail: [dataset creator email]; access.role: OWNER;
This type is not used in any activity, and only used as part of another schema.
Fields
domain: Option<String>[Pick one] A domain to grant access to. Any users signed in with the domain specified will be granted the specified access. Example: “example.com”.
role: Option<String>[Required] Describes the rights granted to the user specified by the other member of the access object. The following string values are supported: READER, WRITER, OWNER.
user_by_email: Option<String>[Pick one] An email address of a user to grant access to. For example: fred@example.com.
special_group: Option<String>[Pick one] A special group to grant access to. Possible values include: projectOwners: Owners of the enclosing project. projectReaders: Readers of the enclosing project. projectWriters: Writers of the enclosing project. allAuthenticatedUsers: All authenticated BigQuery users.
group_by_email: Option<String>[Pick one] An email address of a Google Group to grant access to.
view: Option<TableReference>[Pick one] A view from a different dataset to grant access to. Queries executed against that view will have read access to tables in this dataset. The role field is not required when this field is set. If that view is updated by any user, access to the view needs to be granted again via an update operation.