Struct google_bigquery2::DatasetListDatasets
source · pub struct DatasetListDatasets {
pub friendly_name: Option<String>,
pub kind: Option<String>,
pub labels: Option<HashMap<String, String>>,
pub id: Option<String>,
pub dataset_reference: Option<DatasetReference>,
}Expand description
An array of the dataset resources in the project. Each resource contains basic information. For full information about a particular dataset resource, use the Datasets: get method. This property is omitted when there are no datasets in the project.
This type is not used in any activity, and only used as part of another schema.
Fields
friendly_name: Option<String>A descriptive name for the dataset, if one exists.
kind: Option<String>The resource type. This property always returns the value “bigquery#dataset”.
labels: Option<HashMap<String, String>>The labels associated with this dataset. You can use these to organize and group your datasets.
id: Option<String>The fully-qualified, unique, opaque ID of the dataset.
dataset_reference: Option<DatasetReference>The dataset reference. Use this property to access specific parts of the dataset’s ID, such as project ID or dataset ID.