Struct google_bigquery2::JobConfiguration
source · pub struct JobConfiguration {
pub load: Option<JobConfigurationLoad>,
pub copy: Option<JobConfigurationTableCopy>,
pub dry_run: Option<bool>,
pub query: Option<JobConfigurationQuery>,
pub labels: Option<HashMap<String, String>>,
pub extract: Option<JobConfigurationExtract>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
load: Option<JobConfigurationLoad>[Pick one] Configures a load job.
copy: Option<JobConfigurationTableCopy>[Pick one] Copies a table.
dry_run: Option<bool>[Optional] If set, don’t actually run this job. A valid query will return a mostly empty response with some processing statistics, while an invalid query will return the same error it would if it wasn’t a dry run. Behavior of non-query jobs is undefined.
query: Option<JobConfigurationQuery>[Pick one] Configures a query job.
labels: Option<HashMap<String, String>>[Experimental] The labels associated with this job. You can use these to organize and group your jobs. Label keys and values can be no longer than 63 characters, can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. Label values are optional. Label keys must start with a letter and each label in the list must have a different key.
extract: Option<JobConfigurationExtract>[Pick one] Configures an extract job.