pub struct JobConfigurationExtract {
pub destination_uri: Option<String>,
pub destination_format: Option<String>,
pub compression: Option<String>,
pub destination_uris: Option<Vec<String>>,
pub print_header: Option<bool>,
pub field_delimiter: Option<String>,
pub source_table: Option<TableReference>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
destination_uri: Option<String>[Pick one] DEPRECATED: Use destinationUris instead, passing only one URI as necessary. The fully-qualified Google Cloud Storage URI where the extracted table should be written.
destination_format: Option<String>[Optional] The exported file format. Possible values include CSV, NEWLINE_DELIMITED_JSON and AVRO. The default value is CSV. Tables with nested or repeated fields cannot be exported as CSV.
compression: Option<String>[Optional] The compression type to use for exported files. Possible values include GZIP and NONE. The default value is NONE.
destination_uris: Option<Vec<String>>[Pick one] A list of fully-qualified Google Cloud Storage URIs where the extracted table should be written.
print_header: Option<bool>[Optional] Whether to print out a header row in the results. Default is true.
field_delimiter: Option<String>[Optional] Delimiter to use between fields in the exported data. Default is ‘,’
source_table: Option<TableReference>[Required] A reference to the table being exported.