Struct google_bigquery2::TimePartitioning
source · pub struct TimePartitioning {
pub field: Option<String>,
pub type_: Option<String>,
pub expiration_ms: Option<String>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
field: Option<String>[Experimental] [Optional] If not set, the table is partitioned by pseudo column ‘_PARTITIONTIME’; if set, the table is partitioned by this field. The field must be a top-level TIMESTAMP or DATE field. Its mode must be NULLABLE or REQUIRED.
type_: Option<String>[Required] The only type supported is DAY, which will generate one partition per day.
expiration_ms: Option<String>[Optional] Number of milliseconds for which to keep the storage for a partition.